package com.menagerie.ophelia

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.menagerie.ophelia.ui.theme.OpheliaTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            OpheliaTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = Color.White
                ) {
                    GreetingImage(
                        message = getString(R.string.main_welcome_message),
                        from = getString(R.string.tagline)
                    )
                    arrayDisplay()
                }
            }
        }
    }
}

@Composable
fun GreetingImage(message: String, from: String, modifier: Modifier = Modifier) {
    val image = painterResource(R.drawable.androidparty)
    Box {
        Image(
            painter = image,
            contentDescription = null,
            contentScale = ContentScale.Crop,
            alpha = 0.5F,
        )
        GreetingText(
            message = message,
            from = from,
            modifier = Modifier
                .fillMaxSize()
                .padding(8.dp)
        )
    }
}

@Composable
fun GreetingText(message: String, from: String, modifier: Modifier = Modifier) {
    // Create a column so that texts don't overlap
    Column(
        verticalArrangement = Arrangement.Center,
        modifier = modifier
    ) {
        Text(
            text = message,
            color = Color.Black,
            fontSize = 70.sp,
            lineHeight = 116.sp,
            textAlign = TextAlign.Center
        )
        Text(
            text = from,
            color = Color.Black,
            fontSize = 36.sp,
            modifier = Modifier
                .padding(16.dp)
                .align(alignment = Alignment.CenterHorizontally)
        )
    }
}

//@Preview(showBackground = true)
@Composable
fun BirthdayCardPreview() {
    OpheliaTheme {
        GreetingImage(
            message = stringResource(R.string.main_welcome_message),
            from = stringResource(R.string.tagline)
        )
    }
}

@Preview(showBackground = true)
@Composable
fun arrayDisplayPreview() {
    Column {
        Text(text = "${arrayDisplay()}")
    }
}

@Composable
fun arrayDisplay(): String {

    var ret = ""


    val solarSystem = mutableMapOf(
        "Mercury" to 0,
        "Venus" to 0,
        "Earth" to 1,
        "Mars" to 2,
        "Jupiter" to 79,
        "Saturn" to 82,
        "Uranus" to 27,
        "Neptune" to 14)

    solarSystem["Pluto"] = 5
    ret = printMap(solarSystem)
    return ret
}

fun printArray(array: List<String>): String {
    var print = ""
    var idx = 0
    repeat(array.size) {
        print += array[idx] + " "
        idx++
    }
    return print
}

fun printMap(map: Map<String, Int>): String {
    var keys = map.keys
    var idx = 0
    var print = ""
    repeat(map.size) {
        print += keys.elementAt(idx) + " " + map[keys.elementAt(idx)] + "\n"
        idx++
    }
    return print
}